/*====================================================================

ObjectWeb Transaction Working Group API
Contact: http://www.objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): ______________________________________.

---------------------------------------------------------------------
$Id: XidState.java,v 1.1.1.1 2003/12/01 15:14:18 rouvoy Exp $
====================================================================*/
package org.objectweb.transaction.api.xid;

import org.objectweb.transaction.api.State;

/**
 * <p>
 * The format of XID must follow these rules :
 * <ul>
 *   <li>The Branch Qualifier length must be between 1 and 64</li>
 *   <li>The Transaction Identifier must be between the Branch Qualifier Length + 1
 *         and the Branch Qualifier Length + 64</li>
 *   <li>The Global Transaction Identifier is provided by the first bytes in the 
 *         Transaction Identifier; the following Branch Qualifier Length bytes 
 *         correspond to the Branch Qualifier part of the XID</li>
 * </ul>
 * 
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 * 
 * @adl.id name="XID_STATE" value="xid-state"
 */
public interface XidState 
         extends State 
{
    /**
     * ADL Identifier
     */
    public static final String XID_STATE = "xid-state";
    
    /**
     * Branch Qualifier Minimal Length
     */
    public static int BQUAL_LENGTH_MIN = 1 ;
    
    /**
     * Branch Qualifier Maximal Length
     */
    public static int BQUAL_LENGTH_MAX = 64 ;
    
    /**
     * Transaction Identifier Minimal Length
     */
    public static int TID_LENGTH_MIN = 1 ;  
    
    /**
     * Transaction Identifier Maximal Length
     */  
    public static int TID_LENGTH_MAX = 64 ;
    
    
    /**
     * Defines the value of the Branch Qualifier of the XID
     * 
     * @param bqual - a byte array representing the Branch Qualifier
     */
    public void setBranchQualifier(byte[] bqual);
    
    /**
     * Defines the value of the Format Identifier of the XID
     * 
     * @param fid - the value of the Format Identifier
     */
    public void setFormatId(int fid);    
    
    /**
     * Defines the value of the Global Transaction Identifier
     * 
     * @param gtid - the global transaction identifier
     */
    public void setGlobalTransactionId(byte[] gtid) ;
    
    /**
     * Provides the value of the Branch Qualifier of the XID
     * 
     * @return a byte array representing the Branch Qualifier
     */
    public byte[] getBranchQualifier() ;
    
    /**
     * Provides the value of the Format Identifier used by the implementation
     * 
     * @return the encoded Format Identifier value
     */
    public int getFormatId();
    
    /**
     * Provides the value of the Global Transaction Identifier
     *  
     * @return the encoded Global Transaction Identifier value
     */
    public byte[] getGlobalTransactionId();
}
